package App::chart;

our $DATE = '2014-08-16'; # DATE
our $VERSION = '0.03'; # VERSION

1;
# ABSTRACT: Generate text-based chart

__END__

=pod

=encoding UTF-8

=head1 NAME

App::chart - Generate text-based chart

=head1 VERSION

This document describes version 0.03 of App::chart (from Perl distribution App-chart), released on 2014-08-16.

=head1 SYNOPSIS

See the command-line script L<chart>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-chart>.

=head1 SOURCE

Source repository is at L<https://github.com/sharyanto/perl-App-chart>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-chart>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
